@@ -245,11 +245,20 @@ void _XtInherit(void)
  * cygwin-xfree: http://www.cygwin.com/ml/cygwin-xfree/2003-10/msg00000.html
  */
 
+#ifdef __x86_64__
+asm (".section .trampoline, \"dwx\" \n\
+ .globl _XtInherit        \n\
+ _XtInherit:              \n\
+    jmp *_y(%rip)         \n\
+_y: .quad __XtInherit     \n\
+    .text                 \n");
+#else
 asm (".data\n\
  .globl __XtInherit        \n\
  __XtInherit:      jmp *_y \n\
   _y: .long ___XtInherit   \n\
     .text                 \n");
+#endif
 
 #define _XtInherit __XtInherit
 #endif
