@@ -75,9 +75,6 @@ in this Software without prior written authorization from The Open Group.
 #include <stdio.h>
 #include <errno.h>
 
-#ifdef __UNIXOS2__
-#include <sys/time.h>
-#endif
 
 static TimerEventRec* freeTimerRecs;
 static WorkProcRec* freeWorkRecs;
@@ -731,7 +728,14 @@ WaitLoop:
 #endif
 	return dpy_no;
     }
-    goto WaitLoop;
+    if (block)
+        goto WaitLoop;
+    else {
+#ifdef USE_POLL
+	XtStackFree ((XtPointer) wf.fdlist, fdlist);
+#endif
+        return -1;
+    }
 }
 
 #define IeCallProc(ptr) \
